import {select} from 'd3-selection';

import {appendInfoTooltip} from './info-tooltip';

describe('d3-rendering/tooltips', () => {

    let testDiv;
    beforeEach(() => {
        testDiv = select('body').append('div')
            .attr('id', 'test-div');
    });

    afterEach(() => {
        select('#test-div').remove();
    });

    it('Creates a tooltip widget', () => {
        let tooltipItem;
        testDiv.call(appendInfoTooltip, 'Help text');
        tooltipItem = testDiv.select('.usa-tooltip');
        expect(tooltipItem.size()).toBe(1);
        expect(tooltipItem.select('.usa-tooltip__trigger').attr('data-position')).toBe('right');
        expect(tooltipItem.select('.usa-tooltip__body').html()).toContain('Help text');
    });

    it('Positions the tooltip using the position parameter', () => {
        let tooltipItem;
        testDiv.call(appendInfoTooltip, 'Help text', 'bottom');
        tooltipItem = testDiv.select('.usa-tooltip');
        expect(tooltipItem.select('.usa-tooltip__trigger').attr('data-position')).toBe('bottom');
    });

    it('Uses bound data to create tooltips', () => {
        testDiv
            .selectAll('div')
            .data([{
                helpText: 'Help1'
            }])
            .enter().append('div')
                .attr('class', 'data-div')
                .call(appendInfoTooltip, d => d.helpText);
        expect(testDiv.select('.data-div').html()).toContain('Help1');
    });
});
