import {createSelector} from 'reselect';

import {getTimeRange} from './hydrograph-data-selector';
import {getSelectedParameterCode} from './hydrograph-state-selector';

export const getAllGroundwaterLevels = state => state.groundwaterLevelData.all;

export const getSelectedGroundwaterLevels = createSelector(
    getSelectedParameterCode,
    getTimeRange('current'),
    getAllGroundwaterLevels,
    (parameterCode, timeRange, groundwaterLevelsData) => {
        const parameterCodeDatastream =
            groundwaterLevelsData.find(datastream => datastream.USGSParameterCode === parameterCode);
        if (parameterCodeDatastream && timeRange) {
            const inTimeRangeObservations =
                parameterCodeDatastream.observations.filter(observation => {
                    return observation.epochTime >= timeRange.start && observation.epochTime <= timeRange.end;
                });
            return {
                parameter: {
                    parameterCode: parameterCodeDatastream.USGSParameterCode,
                    name: parameterCodeDatastream.observedPropertyName,
                    description: parameterCodeDatastream.observedPropertyName,
                    unit: parameterCodeDatastream.unitOfMeasureName
                },
                values: inTimeRangeObservations
            };
        } else {
            return null;
        }
    }
);
