import {mount} from '@vue/test-utils';

import USWDSDatePicker from './date-picker.vue';

describe('uswds-components/date-picker', () => {
    it('Renders a basic USWDS date picker', () => {
        const wrapper = mount(USWDSDatePicker, {
            props: {
                id: 'my-unique-id',
                name:'myDatePicker',
                label: 'My date picker label'
            }
        });

        const pickerLabel = wrapper.find('.usa-label');
        expect(pickerLabel.text()).toBe('My date picker label');
        expect(pickerLabel.attributes('id')).toBe('my-unique-id-label');
        expect(pickerLabel.attributes('for')).toBe('my-unique-id');
        expect(wrapper.find('.usa-hint').exists()).toBe(false);
        const dateInput = wrapper.find('#my-unique-id');
        expect(dateInput.exists()).toBe(true);
        expect(dateInput.attributes('name')).toBe('myDatePicker');
        expect(dateInput.attributes('aria-labelledby')).toBe('my-unique-id-label');
        expect(dateInput.attributes('aria-label')).toBe('');
        expect(dateInput.attributes('aria-describedby')).toBe('');
        expect(wrapper.find('.usa-date-picker__wrapper').exists()).toBe(true);
    });

    it('Expects that changing the value of the input emits a changeDate event', async() => {
        const wrapper = mount(USWDSDatePicker, {
            props: {
                id: 'my-unique-id',
                name:'myDatePicker',
                label: 'My date picker label'
            }
        });

        const dateInput = wrapper.find('.usa-date-picker__internal-input');
        dateInput.element.value = '2022-04-23';
        await dateInput.trigger('change');
        expect(wrapper.emitted().changeDate).toHaveLength(1);
        expect(wrapper.emitted().changeDate[0]).toEqual(['2022-04-23']);
    });

    it('Expects that setting showLabel to false does not render the label but sets the aria-label attribute for the input', () => {
        const wrapper = mount(USWDSDatePicker, {
            props: {
                id: 'my-unique-id',
                name:'myDatePicker',
                label: 'My date picker label',
                showLabel: false
            }
        });

        expect(wrapper.find('.usa-label').exists()).toBe(false);
        const dateInput = wrapper.find('#my-unique-id');
        expect(dateInput.attributes('aria-labelledby')).toBe('');
        expect(dateInput.attributes('aria-label')).toBe('My date picker label');
    });

    it('Expects if hintText is used, that the hint text is rendered and the aria-described-by attribute is set on the input', () => {
        const wrapper = mount(USWDSDatePicker, {
            props: {
                id: 'my-unique-id',
                name: 'myDatePicker',
                label: 'My date picker label',
                hintText: 'mm/dd/yyyy'
            }
        });

        const hint = wrapper.find('.usa-hint');
        expect(hint.text()).toBe('mm/dd/yyyy');
        expect(hint.attributes().id).toBe('my-unique-id-hint');
        expect(wrapper.find('#my-unique-id').attributes('aria-describedby')).toBe('my-unique-id-hint');
    });

    it('expects that if the date picker data properties are set the appropriate attributes are set', () => {
        const wrapper = mount(USWDSDatePicker, {
            props: {
                id: 'my-unique-id',
                name: 'myDatePicker',
                label: 'My date picker label',
                minDate: '2020-01-10',
                maxDate: '2020-08-01',
                rangeDate: '2020-07-01',
                dateValue: '2020-03-01'
            }
        });

        const datePicker = wrapper.find('#my-unique-id-date-picker');
        expect(datePicker.attributes('data-min-date')).toBe('2020-01-10');
        expect(datePicker.attributes('data-max-date')).toBe('2020-08-01');
        expect(datePicker.attributes('data-range-date')).toBe('2020-07-01');
        expect(datePicker.attributes('data-default-value')).toBe('2020-03-01');
    });
});

