import {enableFetchMocks, disableFetchMocks} from 'jest-fetch-mock';
import mockConsole from 'jest-mock-console';

import {MOCK_CAMERA_METADATA} from 'ui/mock-service-data';

import {fetchCameraMetaData} from './camera-images';

describe('web-services/camera-images', () => {
    beforeEach(() => {
        enableFetchMocks();
    });

    afterEach(() => {
        disableFetchMocks();
    });

    describe('fetchCameraMetaData', () => {
        let restoreConsole;
        beforeEach(() => {
            fetch.resetMocks();
            restoreConsole = mockConsole();
        });

        afterEach(() => {
            restoreConsole();
        });

        it('puts the site number in the request url and returns valid response data', async() => {
            fetch.once(MOCK_CAMERA_METADATA, {status: 200});
            const resp = await fetchCameraMetaData('05428500');

            expect(fetch.mock.calls).toHaveLength(1);
            expect(fetch.mock.calls[0][0]).toContain('siteID=05428500');
            expect(resp).toEqual(JSON.parse(MOCK_CAMERA_METADATA));
        });


        it('Successful request with no data returns an object with success set to false', async() => {
            fetch.once('No data returned', {status: 200});
            const resp = await fetchCameraMetaData('05428500');

            expect(resp).toEqual({success: false});
        });

        it('handles a 400 bad status', async() => {
            fetch.once('{}', {status: 400});
            const resp = await fetchCameraMetaData('05428500');

            expect(resp).toEqual({success: false});
        });

        it('handles a bad fetch', async() => {
            fetch.mockReject(new Error('fake error message'));
            const resp = await fetchCameraMetaData('05428500');

            expect(resp).toEqual({success: false});
        });
    });
});
