import {enableFetchMocks, disableFetchMocks} from 'jest-fetch-mock';
import mockConsole from 'jest-mock-console';

import {MOCK_WATERWATCH_FLOOD_LEVELS} from 'ui/mock-service-data';

import {fetchFloodLevels} from './flood-levels';

describe('web-services/flood-levels', () => {
    beforeEach(() => {
        enableFetchMocks();
    });

    afterEach(() => {
        disableFetchMocks();
    });

    describe('fetchFloodLevels', () => {
        let restoreConsole;
        beforeEach(() => {
            fetch.resetMocks();
            restoreConsole = mockConsole();
        });

        afterEach(() => {
            restoreConsole();
        });

        it('Valid response with flood levels returns the flood level object', async() => {
            fetch.once(MOCK_WATERWATCH_FLOOD_LEVELS, {status: 200});
            const resp = await fetchFloodLevels('12345678');

            expect(fetch.mock.calls).toHaveLength(1);
            expect(fetch.mock.calls[0][0]).toContain('site=12345678');
            expect(resp).toEqual(JSON.parse(MOCK_WATERWATCH_FLOOD_LEVELS).sites[0]);
        });

        it('valid response without flood levels returns null', async() => {
            fetch.once('{sites:[]}', {status: 200});
            const resp = await fetchFloodLevels('12345678');

            expect(resp).toBeNull();
        });

        it('handles a 400 bad status', async() => {
            fetch.once('{}', {status: 400});
            const resp = await fetchFloodLevels('12345678');

            expect(resp).toBeNull();
        });

        it('handles a bad fetch', async() => {
            fetch.mockReject(new Error('fake error message'));
            const resp = await fetchFloodLevels('12345678');

            expect(resp).toBeNull();
        });
    });
});