import config from 'ui/config';

const NLDI_URL = config.NLDI_SERVICES_ENDPOINT;
const FEATURE_SOURCE = 'nwissite';
const DISTANCE_PARAM = `?distance=${config.NLDI_SERVICES_DISTANCE}`;

const getFeatureId = function(siteno) {
    return `USGS-${siteno}`;
};

/*
 * Retrieve nldi features if any for siteno
 * @param {String} siteno
 * @return {Promise} resolves to an array of features for the site
 */
const fetchNldiData = async function(nldiQuery) {
    try {
        const response = await fetch(nldiQuery, {
            method: 'GET'
        });
        if (response.status === 200) {
            const responseJSON = await response.json();
            return responseJSON.features ? responseJSON.features : [];

        } else {
            console.error(`Received bad status, ${response.status} at ${nldiQuery}`);
            return [];
        }
    } catch (error) {
        console.error(`Failed fetch for ${nldiQuery}`);
        return [];
    }
};

// nldi webservice calls
export const fetchNldiUpstreamFlow = function(siteno) {
    const upstreamFlowQuery = `${NLDI_URL}/${FEATURE_SOURCE}/${getFeatureId(siteno)}/navigation/UM/flowlines${DISTANCE_PARAM}`;
    return fetchNldiData(upstreamFlowQuery);
};

export const fetchNldiDownstreamFlow = function(siteno) {
    const downStreamFlowQuery = `${NLDI_URL}/${FEATURE_SOURCE}/${getFeatureId(siteno)}/navigation/DM/flowlines${DISTANCE_PARAM}`;
    return fetchNldiData(downStreamFlowQuery);
};

export const fetchNldiUpstreamBasin = function(siteno) {
    const upStreamBasinQuery = `${NLDI_URL}/${FEATURE_SOURCE}/${getFeatureId(siteno)}/basin`;
    return fetchNldiData(upStreamBasinQuery);
};
