import {enableFetchMocks, disableFetchMocks} from 'jest-fetch-mock';
import mockConsole from 'jest-mock-console';

import {MOCK_NLDI_UPSTREAM_FLOW_FEATURE, MOCK_NLDI_DOWNSTREAM_FLOW_FEATURE,
    MOCK_NLDI_UPSTREAM_BASIN_FEATURE} from 'ui/mock-service-data';

import {fetchNldiUpstreamFlow, fetchNldiDownstreamFlow, fetchNldiUpstreamBasin} from './nldi-data';

describe('web-services/nldi-data module', () => {
    let restoreConsole;

    beforeEach(() => {
        enableFetchMocks();
        restoreConsole = mockConsole();
    });

    afterEach(() => {
        restoreConsole();
        disableFetchMocks();
    });

    describe('fetchNldiUpstreamFlow', () => {
        const siteno = '12345678';
        beforeEach(() => {
            fetch.resetMocks();
        });

        it('expected response is json object with the upstream flow', async() => {
            fetch.once(MOCK_NLDI_UPSTREAM_FLOW_FEATURE, {status: 200});
            const resp = await fetchNldiUpstreamFlow(siteno);

            expect(fetch.mock.calls).toHaveLength(1);
            expect(resp).toHaveLength(2);
            expect(resp[0].properties.nhdplus_comid).toBe('10286212');
            expect(resp[1].properties.nhdplus_comid).toBe('10286442');
        });

        it('On failed response return an empty feature list', async() => {
            fetch.once('{}', {status: 400});
            const resp = await fetchNldiUpstreamFlow(siteno);

            expect(resp).toHaveLength(0);
        });
    });

    describe('fetchNldiDownstreamFlow', () => {
        const siteno = '12345678';

        beforeEach(() => {
            fetch.resetMocks();
        });

        it('expected response is json object with the downstream flow', async() => {
            fetch.once(MOCK_NLDI_DOWNSTREAM_FLOW_FEATURE, {status: 200});
            const resp = await fetchNldiDownstreamFlow(siteno);

            expect(fetch.mock.calls).toHaveLength(1);
            expect(resp).toHaveLength(2);
            expect(resp[0].properties.nhdplus_comid).toBe('10286213');
            expect(resp[1].properties.nhdplus_comid).toBe('10286443');
        });

        it('handles a 400 bad status', async() => {
            fetch.once('{}', {status: 400});
            const resp = await fetchNldiDownstreamFlow(siteno);

            expect(resp).toHaveLength(0);
        });
    });

    describe('fetchNldiUpstreamBasin', () => {
        const siteno = '12345678';

        beforeEach(() => {
            fetch.resetMocks();
        });

        it('expected response is json object with the upstream basin', async() => {
            fetch.once(MOCK_NLDI_UPSTREAM_BASIN_FEATURE, {status: 200});
            const resp = await fetchNldiUpstreamBasin(siteno);

            expect(fetch.mock.calls).toHaveLength(1);
            expect(resp).toHaveLength(1);
        });

        it('On failed response return an empty feature list', async() => {
            fetch.once('{}', {status: 400});
            const resp = await fetchNldiUpstreamBasin(siteno);

            expect(fetch.mock.calls).toHaveLength(1);
            expect(resp).toHaveLength(0);
        });
    });
});

