import config from 'ui/config';

/**
 * Formats a URL to connect with the Sensor Things API.
 * @param {String} agencySiteNumberCode - combines the Agency Code with the Site Number for example USGS-01646500
 * @param {String} parameterCode - five digit code that uniquely identifies the observed property (parameter)
 * @return {String} URL for Sensor Things API
 */
export const getSensorThingsURL = function(agencySiteNumberCode, parameterCode) {
    const queryString = `ParameterCode eq '${parameterCode}'`;

    return `${config.SENSOR_THINGS_ENDPOINT}Things('${agencySiteNumberCode}')/Datastreams?$filter=properties/${encodeURIComponent(queryString)} `;
};

/**
 * Does the work of contacting the Sensor Things API and returning data
 * @param {String} agencySiteNumberCode - combines the Agency Code with the Site Number for example USGS-01646500
 * @param {String} parameterCode - five digit code that uniquely identifies the observed property
 * @return {Promise} resolves to an empty object or one containing threshold information (and other secondary information)
 */
export const fetchDataFromSensorThings = async function(agencySiteNumberCode, parameterCode) {
    const url = getSensorThingsURL(agencySiteNumberCode, parameterCode);
    try {
        const response = await fetch(url, {
            method: 'GET'
        });
        if (response.status === 200) {
            return await response.json();

        } else {
            console.error(`Received bad status, ${response.status} at ${url}`);
            return {};
        }
    } catch (error) {
        console.error(`Failed fetch for ${url}`);
        return {};
    }
};
