"""
Helpers to retrieve SIFTA cooperator data.
"""

from aiohttp.client_exceptions import ServerDisconnectedError, ClientConnectorError

from .. import app

# pylint: disable=no-member


async def get_cooperators(session, site_no):
    """
    Gets the cooperator data from the SIFTA service

    :param session - instance aiohttp.ClientSession
    :param str site_no: USGS site number
    :returns
        - has_service_error - bool set to true if the request can not be completed.
        - customers - Array of dict
    """
    url = f'{app.config["COOPERATOR_SERVICE_ENDPOINT"]}{site_no}'
    app.logger.debug(f'Requesting data from {url}')  # pylint: disable=no-member

    try:
        async with session.get(url) as response:
            app.logger.debug(f'Retrieved data from {url}')  # pylint: disable=no-member

            if response.status != 200:
                return False, []
            try:
                resp_json = await response.json()
            except ValueError:
                return False, []
            else:
                return False, resp_json.get('Customers', [])
    except (ServerDisconnectedError, ClientConnectorError) as err:
        app.logger.error(f'Sifta server to {site_no} failed with error: {repr(err)}')
        return True, []
